COMMON SHARE1,nx,gam
COMMON SHARE2,x,d,p,u,e

;-----------------------------------------------------------------------
; Procedure READTAB: Reads CMHOG1.0 tabular dumps
;
PRO readtab,filename
COMMON SHARE1,nx,gam
COMMON SHARE2,x,d,p,u,e
nx = 0L
openr,1,filename
readf,1,nx,gam
x = fltarr(nx)
d = fltarr(nx)
p = fltarr(nx)
u = fltarr(nx)
e = fltarr(nx)
FOR i=0,nx-1 DO BEGIN
  readf,1,tx,td,tp,tu
  x[i] = tx
  d[i] = td
  p[i] = tp
  u[i] = tu
  e[i] = 0.5*tu*tu + tp/(gam-1.0)/td
ENDFOR
close,1
END
;-----------------------------------------------------------------------
; Procedure FOUR_PLOT: Plots d,p,u,E as four panels using points
;
PRO four_plot
COMMON SHARE1,nx,gam
COMMON SHARE2,x,d,p,u,e
!P.MULTI=[0,2,2,0,0]
ymin=MIN(d)
ymax=MAX(d)
plot,x,d,YTITLE='DENSITY',psym=6,symsize=.4,YRANGE=[ymin,ymax]
ymin=MIN(p)
ymax=MAX(p)
plot,x,p,YTITLE='PRESSURE',psym=6,symsize=.4,YRANGE=[ymin,ymax]
ymin=MIN(u)
ymax=MAX(u)
plot,x,u,YTITLE='X-VELOCITY',psym=6,symsize=.4,YRANGE=[ymin,ymax]
ymin=MIN(e)
ymax=MAX(e)
plot,x,e,YTITLE='TOTAL ENERGY',psym=6,symsize=.4,YRANGE=[ymin,ymax]
!P.MULTI=0
END
;-----------------------------------------------------------------------
; Procedure ANIM_PLOT: makes animation
;  Input arguments are nfiles = number of files to be plotted
;                      filename = name of starting file
;                      var = name of variable (d,p,u,e)
;  filename must have the format XXXNNNXX where X are characters and NNN
;  are sequential numbers denoting order in time
;    Example: anim_plot,100,'tab000aa','d' = plots 100 frames of d starting
;             with tab000aa
; THIS PROCEDURE MAY NOT WORK IF OTHER WINDOWS HAVE ALREADY BEEN OPENED BY IDL
; ALWAYS RUN THIS PROCEDURE IN A NEW IDL SESSION
;
PRO anim_plot,nfiles,filename,var
COMMON SHARE1,nx,gam
COMMON SHARE2,x,d,p,u,e
;
; Load data into floating point array, incrementing filename
;
nxwin = !D.X_VSIZE
nywin = !D.Y_VSIZE
readtab,filename
data=FLTARR(nx,nfiles)
IF (var EQ 'd') THEN data(*,0) = d(*)
IF (var EQ 'p') THEN data(*,0) = p(*)
IF (var EQ 'u') THEN data(*,0) = u(*)
IF (var EQ 'e') THEN data(*,0) = e(*)
FOR i=1,nfiles-1 DO BEGIN
  number=STRMID(filename,3,3)
  inumber=FIX(number)+1
  IF inumber LT 10 THEN BEGIN
    number=STRING(inumber,FORMAT='(I1)')
    STRPUT,filename,number,5
  ENDIF
  IF inumber GE 10 AND inumber LT 100 THEN BEGIN
    number=STRING(inumber,FORMAT='(I2)')
    STRPUT,filename,number,4
  ENDIF
  IF inumber GE 100 AND inumber LT 1000 THEN BEGIN
    number=STRING(inumber,FORMAT='(I3)')
    STRPUT,filename,number,3
  ENDIF
  IF inumber ge 1000 THEN BEGIN
    print,'ERROR in ANIM_PLOT, Invalid Filename'
    RETURN
  ENDIF
  readtab,filename
  IF (var EQ 'd') THEN data(*,i) = d(*)
  IF (var EQ 'p') THEN data(*,i) = p(*)
  IF (var EQ 'u') THEN data(*,i) = u(*)
  IF (var EQ 'e') THEN data(*,i) = e(*)
ENDFOR
;
; Make plots, save as images
;
dmax = MAX(data)
dmin = MIN(data)
images=BYTARR(nxwin,nywin,nfiles)
FOR i=0,nfiles-1 DO BEGIN
  PLOT,x,data[*,i],PSYM=6,YRANGE=[dmin,dmax]
  PLOT,x,data[*,i],YRANGE=[dmin,dmax]
plot,x,data[*,i],psym=6,symsize=.4,YRANGE=[dmin,dmax]
images[*,*,i]=TVRD(0,0,nxwin,nywin)
ENDFOR
;
; Animate images
;
base=widget_base(title='Animation Widget')
animate = cw_animate(base,nxwin,nywin,nfiles)
widget_control, /realize, base
for i=0,nfiles-1 do cw_animate_load, animate, frame=i, image=images(*,*,i)
cw_animate_getp, animate, pixmap_vect
cw_animate_run, animate
xmanager, 'cw_animate demo', base, event_handler='ehandler'
END

PRO ehandler, ev
widget_control, /destroy, ev.top
END

